Calculates the number of copy number aberrations
cna(
cnvData,
segmentMean = (log(1.7, 2) - 1),
numProbes = NA,
segmentDistance = 0.2,
minSegSize = 10
)dataframe containing following columns: Sample, Start, End, Num_Probes, Segment_Mean
numerical value for the minimum segment_mean cutoff/ threshold. Default is 0.2
Number of Probes
Segment distance threshold
Minimum segment size
Number of copy number aberrations between segments
Copy Number Aberrations (CNA) (Davidson JM, et al), are defined as a segment with copy number outside the pre-defined range of 1.7-2.3 $$(\log_2 1.7 -1) \le \bar{y}_{S_i} \le (\log_2 2.3 -1)$$ that is not contiguous with an adjacent independent CNA of identical copy number. For our purposes, we have adapted the range to be $$|\bar{y}_{S_i}| \ge |\log_2 1.7|$$, which is only slightly larger than the original. It is nearly identical to countingBreakPoints, except this one calculates breaks as adjacent segments that have a difference in segment means of \(\ge 0.2\). $$Total\ Copy\ Number\ Aberration = \sum^{R}_{i = 1} n_i \ where \ \bar{y}_{S_i}| \ge |\log_2{1.7}|, \ \bar{y}_{S_{i-1}} - \bar{y}_{S_i}| \ge 0.2, \ d_i \ge 10$$
# NOT RUN {
cna(cnvData = maskCNV_BRCA)
# }
Run the code above in your browser using DataLab