Total Aberration Index calculation takes the sum of lengths of each segment
times its segmentation mean for each sample and divides it by the sum of the
lengths of each sample.
Usage
tai(cnvData, segmentMean = 0.2, numProbes = NA)
Arguments
cnvData
dataframe containing following columns: Sample, Start, End, Num_Probes, Segment_Mean
segmentMean
numerical value for the minimum segment_mean cutoff/ threshold. Default is 0.2
numProbes
Number of Probes
Value
Average of lengths weighted by segmentation mean for each unique sample
Details
The Total Aberration Index (TAI) (Baumbusch LO, et. al.) is ``a measure of the abundance of genomic size of copy number changes in a tumour".
It is defined as a weighted sum of the segment means
$$
Total\ Aberration\ Index =
\frac
{\sum^{R}_{i = 1} {d_i} \cdot |{\bar{y}_{S_i}}|}
{\sum^{R}_{i = 1} {d_i}}\ \
where |\bar{y}_{S_i}| \ge |\log_2 1.7|
$$